==> haskell-persistent-qq-2.9.1-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-qq
version: 2.9.1
id: persistent-qq-2.9.1-Am231EYWutxGioUaBjesAJ
key: persistent-qq-2.9.1-Am231EYWutxGioUaBjesAJ
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
homepage: https://github.com/yesodweb/persistent#readme
synopsis: Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: eeda957ef006a3209238f42f57f32eff
exposed: True
exposed-modules:
    Database.Persist.Sql.Raw.QQ
hidden-modules: Paths_persistent_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-qq-2.9.1
hs-libraries: HSpersistent-qq-2.9.1-Am231EYWutxGioUaBjesAJ
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-1OTsaYpDy4pHAhu3Huwtu9
    mtl-2.2.2 persistent-2.9.2-3u8mTjXoGWf7WTPndodnQb
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock
haddock-html: /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.9.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-qq
version: 2.9.1
id: persistent-qq-2.9.1-1aoSyChpUfR8EyrdkmqEpA
key: persistent-qq-2.9.1-1aoSyChpUfR8EyrdkmqEpA
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
homepage: https://github.com/yesodweb/persistent#readme
synopsis: Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: 6aef46cea4feca46c978485064544ed7
exposed: True
exposed-modules:
    Database.Persist.Sql.Raw.QQ
hidden-modules: Paths_persistent_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-qq-2.9.1
hs-libraries: HSpersistent-qq-2.9.1-1aoSyChpUfR8EyrdkmqEpA
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-1OTsaYpDy4pHAhu3Huwtu9
    mtl-2.2.2 persistent-2.9.2-GzfCUEBBN4D3ipNmdzKu2e
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock
haddock-html: /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
